@@ -2,7 +2,7 @@ package RedisDB;
 
 use strict;
 use warnings;
-our $VERSION = "2.47";
+our $VERSION = "2.49";
 $VERSION = eval $VERSION;
 
 use RedisDB::Error;
@@ -15,6 +15,8 @@ use Config;
 use Carp;
 use Try::Tiny;
 use Encode qw();
+use URI;
+use URI::redis;
 
 =head1 NAME
 
@@ -69,6 +71,13 @@ connecting to the server. Database changes when you sending I<select> command
 to the server. You can get current database using I<selected_database> method.
 Default value is 0.
 
+=item url
+
+A Redis URL as described in L<URI::redis>.
+
+You cannot use C<url> together with any of C<host>, C<port>, C<path>,
+C<password>, C<database>.
+
 =item raise_error
 
 By default if redis-server returned error reply, or there was a connection
@@ -138,6 +147,13 @@ sub new {
     if ( $self->{path} and ( $self->{host} or $self->{port} ) ) {
         croak "You can't specify \"path\" together with \"host\" and \"port\"";
     }
+    if ( $self->{url} ) {
+        if ( $self->{host} or $self->{port} or $self->{path} ) {
+            croak "You can't specify \"url\" together with \"host\", \"port\" and \"path\"";
+        }
+
+        $self->_parse_url( $self->{url} );
+    }
     $self->{port} ||= 6379;
     $self->{host} ||= 'localhost';
     $self->{raise_error}    = 1 unless exists $self->{raise_error};
@@ -152,6 +168,22 @@ sub new {
     return $self;
 }
 
+sub _parse_url {
+    my ($self, $url) = @_;
+
+    my $uri = URI->new($url);
+
+    if ( $uri->scheme !~ /^redis/ ) {
+        die "Unknown URL scheme '" . $uri->scheme . "' in URL '$url'";
+    }
+
+    $self->{host}     = $uri->host;
+    $self->{port}     = $uri->port;
+    $self->{path}     = $uri->socket_path;
+    $self->{password} = $uri->password;
+    $self->{database} = $uri->database;
+}
+
 sub _is_redisdb_error {
     ref(shift) =~ /^RedisDB::Error/;
 }
@@ -1726,7 +1758,7 @@ Pavel Shaydo, C<< <zwon at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2015 Pavel Shaydo.
+Copyright 2011-2016 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
