@@ -2,7 +2,7 @@ package RedisDB::Cluster;
 
 use strict;
 use warnings;
-our $VERSION = "2.47";
+our $VERSION = "2.49";
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -147,8 +147,11 @@ This module allows you to access redis cluster.
 
 =head2 $self->new(startup_nodes => \@nodes)
 
-create a new connection to cluster. Startup nodes are used to retrieve
-information about all cluster nodes and slots mappings.
+create a new connection to cluster. Startup nodes should contain array of
+hashes that contains addresses of some nodes in the cluster. Each hash should
+contain 'host' and 'port' elements. Constructor will try to connect to nodes
+from the list and from the first node to which it will be able to connect it
+will retrieve information about all cluster nodes and slots mappings.
 
 =cut
 
@@ -656,7 +659,7 @@ Pavel Shaydo, C<< <zwon at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2015 Pavel Shaydo.
+Copyright 2011-2016 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
