@@ -1,7 +1,7 @@
 package Test::RedisDB;
 use strict;
 use warnings;
-our $VERSION = "2.47";
+our $VERSION = "2.49";
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -139,6 +139,18 @@ sub redisdb_client {
     return RedisDB->new(host => 'localhost', port => $self->{port}, @_);
 }
 
+=head2 $self->url
+
+return URL for the server
+
+=cut
+
+sub url {
+    my $self = shift;
+
+    return 'redis://' . ($self->{password} ? ":$self->{password}@" : "") . "localhost:$self->{port}";
+}
+
 1;
 
 __END__
@@ -149,7 +161,7 @@ Pavel Shaydo, C<< <zwon at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2015 Pavel Shaydo.
+Copyright 2011-2016 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
